<?php
namespace Ep\Woo\Form\Element;

use Interop\Container\ContainerInterface;
use Zend\Form\ElementFactory;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class PopupFactory
 *
 * @package Ep\Woo\Form\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class ProductEnquiryFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $factory = new ElementFactory();
        /** @var ProductEnquiry $popup */
        $popup = $factory($container, $requestedName, $options);

        $config = $container->get('config')['webshop']['product_enquiry'] ?? [];
        $popupId = $config['popup_id'] ?? false;

        if ($popupId) {
            $classes = $popup->getAttribute('class') ?: '';
            $classes = sprintf('%s spu-open-%d', $classes, $popupId);
            $popup->setAttribute('class', $classes);
        }

        if ($label = ($config['button_label'] ?? '')) {
            $popup->setLabel($label);
        }

        $popup->setAttributes([
            'data-name-field' => $config['name_field'] ?? '',
            'data-sku-field' => $config['sku_field'] ?? '',
        ]);

        return $popup;
    }
}